Coverage report

File | class | statements | missing | excluded | coverage
--- | --- | --- | --- | --- | ---
signals/__init__.py | (no class) | 0 | 0 | 0 | 100%
signals/dispatch/__init__.py | (no class) | 2 | 0 | 0 | 100%
signals/dispatch/dispatcher.py | Receiver | 0 | 0 | 0 | 100%
signals/dispatch/dispatcher.py | Signal | 167 | 65 | 0 | 61%
signals/dispatch/dispatcher.py | (no class) | 50 | 0 | 0 | 100%
signals/global_settings.py | (no class) | 1 | 0 | 0 | 100%
signals/test/__init__.py | (no class) | 0 | 0 | 0 | 100%
signals/test/utils.py | (no class) | 7 | 1 | 0 | 86%
signals/utils/__init__.py | (no class) | 0 | 0 | 0 | 100%
signals/utils/inspect.py | (no class) | 14 | 1 | 0 | 93%
tests/__init__.py | (no class) | 0 | 0 | 0 | 100%
tests/settings.py | (no class) | 0 | 0 | 0 | 100%
tests/test_dispatch/__init__.py | (no class) | 0 | 0 | 0 | 100%
tests/test_dispatch/test_dispatch.py | Callable | 2 | 1 | 0 | 50%
tests/test_dispatch/test_dispatch.py | TestDispatcher | 156 | 3 | 0 | 98%
tests/test_dispatch/test_dispatch.py | TestDispatcher.test_garbage_collected_sender.Sender | 0 | 0 | 0 | 100%
tests/test_dispatch/test_dispatch.py | TestDispatcher.test_cached_garbaged_collected.sender | 0 | 0 | 0 | 100%
tests/test_dispatch/test_dispatch.py | TestReceiver | 14 | 0 | 0 | 100%
tests/test_dispatch/test_dispatch.py | (no class) | 46 | 0 | 0 | 100%
Total |  | 459 | 71 | 0 | 85%

No items found using the specified filter.